==> owncloud-4.5.7.tgz: owncloud/settings/l10n/ro.php <==
<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Imposibil de încărcat lista din App Store",
"Authentication error" => "Eroare de autentificare",
"Group already exists" => "Grupul există deja",
"Unable to add group" => "Nu s-a putut adăuga grupul",
"Could not enable app. " => "Nu s-a putut activa aplicația.",
"Email saved" => "E-mail salvat",
"Invalid email" => "E-mail nevalid",
"OpenID Changed" => "OpenID schimbat",
"Invalid request" => "Cerere eronată",
"Unable to delete group" => "Nu s-a putut șterge grupul",
"Unable to delete user" => "Nu s-a putut șterge utilizatorul",
"Language changed" => "Limba a fost schimbată",
"Unable to add user to group %s" => "Nu s-a putut adăuga utilizatorul la grupul %s",
"Unable to remove user from group %s" => "Nu s-a putut elimina utilizatorul din grupul %s",
"Disable" => "Dezactivați",
"Enable" => "Activați",
"Saving..." => "Salvez...",
"__language_name__" => "_language_name_",
"Security Warning" => "Avertisment de securitate",
"Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Directorul tău de date și fișierele tale probabil sunt accesibile prin internet. Fișierul .htaccess oferit de ownCloud nu funcționează. Îți recomandăm să configurezi server-ul tău web într-un mod în care directorul de date să nu mai fie accesibil sau mută directorul de date în afara directorului root al server-ului web.",
"Cron" => "Cron",
"Execute one task with each page loaded" => "Execută o sarcină la fiecare pagină încărcată",
"cron.php is registered at a webcron service. Call the cron.php page in the owncloud root once a minute over http." => "cron.php este înregistrat în serviciul webcron. Accesează pagina cron.php din root-ul owncloud odată pe minut prin http.",
"Use systems cron service. Call the cron.php file in the owncloud folder via a system cronjob once a minute." => "Folosește serviciul cron al sistemului. Accesează fișierul cron.php din directorul owncloud printr-un cronjob de sistem odată la fiecare minut.",
"Sharing" => "Partajare",
"Enable Share API" => "Activare API partajare",
"Allow apps to use the Share API" => "Permite aplicațiilor să folosească API-ul de partajare",
"Allow links" => "Pemite legături",
"Allow users to share items to the public with links" => "Permite utilizatorilor să partajeze fișiere în mod public prin legături",
"Allow resharing" => "Permite repartajarea",
"Allow users to share items shared with them again" => "Permite utilizatorilor să repartajeze fișiere partajate cu ei",
"Allow users to share with anyone" => "Permite utilizatorilor să partajeze cu oricine",
"Allow users to only share with users in their groups" => "Permite utilizatorilor să partajeze doar cu utilizatori din același grup",
"Log" => "Jurnal de activitate",
"More" => "Mai mult",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Dezvoltat de the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">comunitatea ownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">codul sursă</a> este licențiat sub <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Adaugă aplicația ta",
"Select an App" => "Selectează o aplicație",
"See application page at apps.owncloud.com" => "Vizualizează pagina applicației pe apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licențiat <span class=\"author\"></span>",
"Documentation" => "Documetație",
"Managing Big Files" => "Gestionînd fișiere mari",
"Ask a question" => "Întreabă",
"Problems connecting to help database." => "Probleme de conectare la baza de date.",
"Go there manually." => "Pe cale manuală.",
"Answer" => "Răspuns",
"You have used <strong>%s</strong> of the available <strong>%s<strong>" => "Ai utilizat <strong>%s</strong> din <strong>%s<strong> spațiu disponibil",
"Desktop and Mobile Syncing Clients" => "Clienți de sincronizare pentru telefon mobil și desktop",
"Download" => "Descărcări",
"Your password was changed" => "Parola a fost modificată",
"Unable to change your password" => "Imposibil de-ați schimbat parola",
"Current password" => "Parola curentă",
"New password" => "Noua parolă",
"show" => "afișează",
"Change password" => "Schimbă parola",
"Email" => "Email",
"Your email address" => "Adresa ta de email",
"Fill in an email address to enable password recovery" => "Completează o adresă de mail pentru a-ți putea recupera parola",
"Language" => "Limba",
"Help translate" => "Ajută la traducere",
"use this address to connect to your ownCloud in your file manager" => "folosește această adresă pentru a te conecta la managerul tău de fișiere din ownCloud",
"Name" => "Nume",
"Password" => "Parolă",
"Groups" => "Grupuri",
"Create" => "Crează",
"Default Quota" => "Cotă implicită",
"Other" => "Altele",
"Group Admin" => "Grupul Admin ",
"Quota" => "Cotă",
"Delete" => "Șterge"
);

==> owncloud-5.0.9.tgz: owncloud/settings/l10n/ro.php <==
<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Imposibil de încărcat lista din App Store",
"Authentication error" => "Eroare de autentificare",
"Group already exists" => "Grupul există deja",
"Unable to add group" => "Nu s-a putut adăuga grupul",
"Could not enable app. " => "Nu s-a putut activa aplicația.",
"Email saved" => "E-mail salvat",
"Invalid email" => "E-mail nevalid",
"Unable to delete group" => "Nu s-a putut șterge grupul",
"Unable to delete user" => "Nu s-a putut șterge utilizatorul",
"Language changed" => "Limba a fost schimbată",
"Invalid request" => "Cerere eronată",
"Admins can't remove themself from the admin group" => "Administratorii nu se pot șterge singuri din grupul admin",
"Unable to add user to group %s" => "Nu s-a putut adăuga utilizatorul la grupul %s",
"Unable to remove user from group %s" => "Nu s-a putut elimina utilizatorul din grupul %s",
"Disable" => "Dezactivați",
"Enable" => "Activați",
"Error" => "Eroare",
"Saving..." => "Salvez...",
"deleted" => "șters",
"undo" => "Anulează ultima acțiune",
"Groups" => "Grupuri",
"Group Admin" => "Grupul Admin ",
"Delete" => "Șterge",
"__language_name__" => "_language_name_",
"Security Warning" => "Avertisment de securitate",
"Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Directorul tău de date și fișierele tale probabil sunt accesibile prin internet. Fișierul .htaccess oferit de ownCloud nu funcționează. Îți recomandăm să configurezi server-ul tău web într-un mod în care directorul de date să nu mai fie accesibil sau mută directorul de date în afara directorului root al server-ului web.",
"More" => "Mai mult",
"Version" => "Versiunea",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Dezvoltat de the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">comunitatea ownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">codul sursă</a> este licențiat sub <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Adaugă aplicația ta",
"More Apps" => "Mai multe aplicații",
"Select an App" => "Selectează o aplicație",
"See application page at apps.owncloud.com" => "Vizualizează pagina applicației pe apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licențiat <span class=\"author\"></span>",
"Update" => "Actualizare",
"User Documentation" => "Documentație utilizator",
"Administrator Documentation" => "Documentație administrator",
"Online Documentation" => "Documentație online",
"Forum" => "Forum",
"Bugtracker" => "Urmărire bug-uri",
"Commercial Support" => "Suport comercial",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Ați utilizat <strong>%s</strong> din <strong>%s</strong> disponibile",
"Password" => "Parolă",
"Your password was changed" => "Parola a fost modificată",
"Unable to change your password" => "Imposibil de-ați schimbat parola",
"Current password" => "Parola curentă",
"New password" => "Noua parolă",
"Change password" => "Schimbă parola",
"Email" => "Email",
"Your email address" => "Adresa ta de email",
"Fill in an email address to enable password recovery" => "Completează o adresă de mail pentru a-ți putea recupera parola",
"Language" => "Limba",
"Help translate" => "Ajută la traducere",
"WebDAV" => "WebDAV",
"Use this address to connect to your ownCloud in your file manager" => "Folosește această adresă pentru a conecta ownCloud cu managerul de fișiere",
"Create" => "Crează",
"Default Storage" => "Stocare implicită",
"Unlimited" => "Nelimitată",
"Other" => "Altele",
"Storage" => "Stocare",
"Default" => "Implicită"
);
